@@ -50,7 +50,7 @@ using namespace KIO;
 
 static QString homeTmpDir()
 {
-    return QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QDir::separator();
+    return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QDir::separator();
 }
 static QString destDir()
 {
@@ -284,7 +284,7 @@ void FileUndoManagerTest::testCopyFiles()
     m_uiInterface->setNextReplyToConfirmDeletion(false);   // act like the user didn't confirm
     FileUndoManager::self()->undo();
     QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files()[0].toString(), QUrl::fromLocalFile(destFile()).toString());
+    QCOMPARE(m_uiInterface->files().constFirst().toString(), QUrl::fromLocalFile(destFile()).toString());
     QVERIFY(QFile::exists(destFile()));     // nothing happened yet
 
     // OK, now do it
@@ -296,7 +296,7 @@ void FileUndoManagerTest::testCopyFiles()
     QVERIFY(spyUndoAvailable.count() >= 2);   // it's in fact 3, due to lock/unlock emitting it as well
     QCOMPARE(spyTextChanged.count(), 2);
     QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files()[0].toString(), QUrl::fromLocalFile(destFile()).toString());
+    QCOMPARE(m_uiInterface->files().constFirst().toString(), QUrl::fromLocalFile(destFile()).toString());
 
     // Check that undo worked
     QVERIFY(!QFile::exists(destFile()));
@@ -453,7 +453,7 @@ void FileUndoManagerTest::testCreateSymlink()
     createTestFile(targetPath, "Link's Target");
     QVERIFY(QFile::exists(targetPath));
 
-    KIO::CopyJob *job = KIO::link(target, link);
+    KIO::CopyJob *job = KIO::link(target, link, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordCopyJob(job);
     bool ok = job->exec();
@@ -485,7 +485,7 @@ void FileUndoManagerTest::testCreateDir()
     m_uiInterface->setNextReplyToConfirmDeletion(false);   // act like the user didn't confirm
     FileUndoManager::self()->undo();
     QCOMPARE(m_uiInterface->files().count(), 1);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files()[0].toString(), url.toString());
+    QCOMPARE(m_uiInterface->files().constFirst().toString(), url.toString());
     QVERIFY(QFile::exists(path));   // nothing happened yet
 
     // OK, now do it
@@ -503,7 +503,7 @@ void FileUndoManagerTest::testMkpath()
     QVERIFY(!QFile::exists(path));
     const QUrl url = QUrl::fromLocalFile(path);
 
-    KIO::Job *job = KIO::mkpath(url);
+    KIO::Job *job = KIO::mkpath(url, QUrl(), KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::Mkpath, QList<QUrl>(), url, job);
     QVERIFY(job->exec());
@@ -514,9 +514,10 @@ void FileUndoManagerTest::testMkpath()
     doUndo();
 
     QVERIFY(!FileUndoManager::self()->undoAvailable());
-    QCOMPARE(m_uiInterface->files().count(), 2);   // confirmDeletion was called
-    QCOMPARE(m_uiInterface->files()[0].toLocalFile(), path);
-    QCOMPARE(m_uiInterface->files()[1].toLocalFile(), parent);
+    const auto files = m_uiInterface->files();
+    QCOMPARE(files.count(), 2);   // confirmDeletion was called
+    QCOMPARE(files[0].toLocalFile(), path);
+    QCOMPARE(files[1].toLocalFile(), parent);
 
     QVERIFY(!QFile::exists(path));
 }
@@ -653,7 +654,7 @@ void FileUndoManagerTest::testPasteClipboardUndo()
 
     // Paste the contents of the clipboard and check its status
     QUrl destDirUrl = QUrl::fromLocalFile(destDir());
-    KIO::Job *job = KIO::paste(mimeData, destDirUrl);
+    KIO::Job *job = KIO::paste(mimeData, destDirUrl, KIO::HideProgressInfo);
     QVERIFY(job);
     QVERIFY(job->exec());
 
@@ -686,7 +687,7 @@ void FileUndoManagerTest::testBatchRename()
     createTestFile(srcList.at(1).path(), "foo");
     createTestFile(srcList.at(2).path(), "foo");
 
-    KIO::Job *job = KIO::batchRename(srcList, QLatin1String("newfile###"), 1, QLatin1Char('#'));
+    KIO::Job *job = KIO::batchRename(srcList, QLatin1String("newfile###"), 1, QLatin1Char('#'), KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     FileUndoManager::self()->recordJob(FileUndoManager::BatchRename, srcList, QUrl(), job);
     QVERIFY2(job->exec(), qPrintable(job->errorString()));
