@@ -1,35 +1,24 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfileitemtest.h"
 #include <kfileitemlistproperties.h>
-#include <qtest.h>
+#include <QTest>
 #include <kfileitem.h>
 
-#include <qtemporarydir.h>
-#include <qtemporaryfile.h>
-#include <kuser.h>
-#include <kdesktopfile.h>
-#include <kconfiggroup.h>
+#include <QTemporaryDir>
+#include <QTemporaryFile>
+#include <KUser>
+#include <KDesktopFile>
+#include <KConfigGroup>
 #include "kiotesthelper.h"
 
 #include <QMimeDatabase>
+#include <KProtocolInfo>
 
 QTEST_MAIN(KFileItemTest)
 
@@ -560,10 +549,20 @@ void KFileItemTest::testListProperties()
             }
             QFile file(fileName);
             QVERIFY(file.open(QIODevice::WriteOnly));
-            if (i != 2) { // 3rd file is empty
+            if (i == 0) {
                 file.write("Hello");
-            }
-            items << KFileItem(QUrl::fromLocalFile(fileName), QString(), KFileItem::Unknown);
+            } else if (i == 1) {
+                file.write("<html>");
+            } // i == 2: leave the file empty
+            file.close();
+            KFileItem item(QUrl::fromLocalFile(fileName), QString(), KFileItem::Unknown);
+            if (i == 0)
+                QCOMPARE(item.mimetype(), "text/plain");
+            else if (i == 1)
+                QCOMPARE(item.mimetype(), "text/html");
+            else if (i == 2)
+                QCOMPARE(item.mimetype(), "application/x-zerosize");
+            items.push_back(std::move(item));
         }
         break;
         case 'd':
@@ -595,13 +594,13 @@ void KFileItemTest::testIconNameForUrl_data()
     QTest::addColumn<QUrl>("url");
     QTest::addColumn<QString>("expectedIcon");
 
-    QTest::newRow("root") << QUrl("file:/") << "folder"; // the icon comes from KProtocolInfo
+    QTest::newRow("root") << QUrl("file:/") << "inode-directory"; // the icon comes from KFileItem
     if (QFile::exists(QStringLiteral("/tmp"))) {
         QTest::newRow("subdir") << QUrl::fromLocalFile("/tmp") << "folder-temp";
     }
 
     QTest::newRow("home") << QUrl::fromLocalFile(QDir::homePath()) << "user-home";
-    const QString moviesPath = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first();
+    const QString moviesPath = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).constFirst();
     if (QFileInfo::exists(moviesPath)) {
         QTest::newRow("videos") << QUrl::fromLocalFile(moviesPath) << (moviesPath == QDir::homePath() ? "user-home" : "folder-videos");
     }
@@ -610,7 +609,19 @@ void KFileItemTest::testIconNameForUrl_data()
     QTest::newRow("relative") << QUrl("foo") << "unknown";
     QTest::newRow("tilde") << QUrl("~") << "unknown";
 
-    // TODO more tests
+    QTest::newRow("unknownscheme folder") << QUrl("unknownscheme:/") << "inode-directory";
+    QTest::newRow("unknownscheme file") << QUrl("unknownscheme:/test") << "application-octet-stream";
+
+    QTest::newRow("trash:/ itself") << QUrl("trash:/") << "user-trash-full";
+    QTest::newRow("folder under trash:/") << QUrl("trash:/folder/") << "inode-directory";
+    QTest::newRow("file under trash:/") << QUrl("trash:/test") << "application-octet-stream";
+
+    QTest::newRow("https scheme") << QUrl("https://kde.org/") << "text-html";
+
+    if (KProtocolInfo::isKnownProtocol("smb")) {
+        QTest::newRow("smb folder") << QUrl("smb:/") << "network-workgroup";
+        QTest::newRow("smb file") << QUrl("smb:/test") << "network-workgroup";
+    }
 }
 
 void KFileItemTest::testIconNameForUrl()
@@ -772,7 +783,7 @@ void KFileItemTest::testNonWritableDirectory()
 
     // When using KFileItemListProperties on the file
     const KFileItem item(QUrl::fromLocalFile(file.fileName()));
-    KFileItemListProperties props(KFileItemList() << item);
+    KFileItemListProperties props(KFileItemList{item});
 
     // Then it should say moving is not supported
     QVERIFY(!props.supportsMoving());
