@@ -1,20 +1,8 @@
 /*
- *  Copyright (C) 2013 Mark Gaiser <markg85@gmail.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Mark Gaiser <markg85@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "listdirtest.h"
 
@@ -55,7 +43,7 @@ void ListDirTest::numFilesTestCase()
         job->setUiDelegate(nullptr);
         connect(job, &KIO::ListJob::entries, this, &ListDirTest::slotEntries);
 
-        QSignalSpy spy(job, SIGNAL(result(KJob*)));
+        QSignalSpy spy(job, &KJob::result);
         QVERIFY(spy.wait(100000));
         QCOMPARE(job->error(), 0); // no error
     }
