@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2000 Stephan Kulow <coolo@kde.org>
-    Copyright (C) 2000-2013 David Faure <faure@kde.org>
-    Copyright (C) 2006 Kevin Ottens <ervin@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 2000-2013 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_JOBUIDELEGATEEXTENSION_H
@@ -33,30 +21,26 @@ class Job;
 class ClipboardUpdater;
 
 /**
- * RenameDialog_Overwrite: We have an existing dest, show details about it and offer to overwrite it.
- * RenameDialog_OverwriteItself: Warn that the current operation would overwrite a file with itself,
- *                     which is not allowed.
- * RenameDialog_Skip: Offer a "Skip" button, to skip other files too. Requires RenameDialog_MultipleItems.
- * RenameDialog_MultipleItems: Set if the current operation concerns multiple files, so it makes sense
- *  to offer buttons that apply the user's choice to all files/folders.
- * RenameDialog_Resume: Offer a "Resume" button (plus "Resume All" if RenameDialog_MultipleItems).
- * RenameDialog_NoRename: Don't offer a "Rename" button
- * RenameDialog_IsDirectory: The dest is a directory, so label the "overwrite" button something like "merge" instead.
+ * @see RenameDialog_Options
  * @since 5.0
  */
 enum RenameDialog_Option {
-    RenameDialog_Overwrite = 1,
-    RenameDialog_OverwriteItself = 2,
-    RenameDialog_Skip = 4,
-    RenameDialog_MultipleItems = 8,
-    RenameDialog_Resume = 16,
-    RenameDialog_NoRename = 64,
-    RenameDialog_IsDirectory = 128
+    RenameDialog_Overwrite = 1, ///< We have an existing destination, show details about it and offer to overwrite it.
+    RenameDialog_OverwriteItself = 2, ///< Warn that the current operation would overwrite a file with itself, which is not allowed.
+    RenameDialog_Skip = 4, ///< Offer a "Skip" button, to skip other files too. Requires RenameDialog_MultipleItems.
+    RenameDialog_MultipleItems = 8, ///< Set if the current operation concerns multiple files, so it makes sense to offer buttons that apply the user's choice to all files/folders.
+    RenameDialog_Resume = 16, ///< Offer a "Resume" button (plus "Resume All" if RenameDialog_MultipleItems).
+    RenameDialog_NoRename = 64, ///< Don't offer a "Rename" button.
+    RenameDialog_IsDirectory = 128 ///< The destination is a directory, the dialog updates labels and tooltips accordingly.
 };
+/**
+ * Stores a combination of #RenameDialog_Option values.
+ */
 Q_DECLARE_FLAGS(RenameDialog_Options, RenameDialog_Option)
+Q_DECLARE_OPERATORS_FOR_FLAGS(RenameDialog_Options)
 
 // For compat
-#ifndef KIOCORE_NO_DEPRECATED
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
 /**
  * @deprecated since 5.0, use the RenameDialog_Option enum values
  */
@@ -72,20 +56,25 @@ enum {
 /**
  * @deprecated since 5.0, use RenameDialog_Options
  */
-#ifndef KIOCORE_NO_DEPRECATED
-KIOCORE_DEPRECATED typedef RenameDialog_Options RenameDialog_Mode;
-#endif
+KIOCORE_DEPRECATED_VERSION(5, 0, "Use KIO::RenameDialog_Options")
+typedef RenameDialog_Options RenameDialog_Mode;
 #endif
 
 /**
  * SkipDialog_MultipleItems: Set if the current operation concerns multiple files, so it makes sense
  *  to offer buttons that apply the user's choice to all files/folders.
+ * @see SkipDialog_Options
  * @since 5.0
  */
 enum SkipDialog_Option {
     SkipDialog_MultipleItems = 8
 };
+/**
+ * Stores a combination of #SkipDialog_Option values.
+ */
 Q_DECLARE_FLAGS(SkipDialog_Options, SkipDialog_Option)
+Q_DECLARE_OPERATORS_FOR_FLAGS(SkipDialog_Options)
+
 
 /**
  * The result of a rename or skip dialog
@@ -102,7 +91,8 @@ enum RenameDialog_Result {
     Result_AutoRename = 8,
     Result_Retry = 9,
 
-    // @deprecated since 5.0, use the RenameDialog_Option enum values
+    // @deprecated since 5.0, use the undeprecated enum values
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     R_CANCEL = Result_Cancel,
     R_RENAME = Result_Rename,
     R_SKIP = Result_Skip,
@@ -118,6 +108,7 @@ enum RenameDialog_Result {
     S_SKIP = Result_Skip,
     S_AUTO_SKIP = Result_AutoSkip,
     S_RETRY = Result_Retry
+#endif
 };
 typedef RenameDialog_Result SkipDialog_Result;
 
@@ -227,7 +218,9 @@ public:
         WarningContinueCancel = 3,
         WarningYesNoCancel = 4,
         Information = 5,
-        SSLMessageBox = 6
+        SSLMessageBox = 6,
+        //In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionYesNoCancel = 9
+        WarningContinueCancelDetailed = 10,
     };
 
     /**
@@ -267,6 +260,8 @@ public:
      */
     virtual void updateUrlInClipboard(const QUrl &src, const QUrl &dest);
 
+    // TODO KF6: add virtual_hook
+
 private:
     class Private;
     Private *const d;
@@ -274,7 +269,7 @@ private:
 
 /**
  * Returns the default job UI delegate extension to be used by all KIO jobs (in which HideProgressInfo is not set)
- * Can return NULL, if no kio GUI library is loaded.
+ * Can return nullptr, if no kio GUI library is loaded.
  * @since 5.0
  */
 KIOCORE_EXPORT JobUiDelegateExtension *defaultJobUiDelegateExtension();
@@ -288,7 +283,4 @@ KIOCORE_EXPORT void setDefaultJobUiDelegateExtension(JobUiDelegateExtension *ext
 
 } // namespace KIO
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(KIO::RenameDialog_Options)
-Q_DECLARE_OPERATORS_FOR_FLAGS(KIO::SkipDialog_Options)
-
 #endif
