@@ -1,26 +1,11 @@
 /*
- * This file is part of the KDE project.
- *
- * Copyright (C) 2008 Alex Merry <alex.merry @ kdemail.net>
- * Copyright (C) 2008 - 2009 Urs Wolfer <uwolfer @ kde.org>
- * Copyright (C) 2009 - 2012 Dawit Alemayehu <adawit @ kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE project.
+    SPDX-FileCopyrightText: 2008 Alex Merry <alex.merry @ kdemail.net>
+    SPDX-FileCopyrightText: 2008-2009 Urs Wolfer <uwolfer @ kde.org>
+    SPDX-FileCopyrightText: 2009-2012 Dawit Alemayehu <adawit @ kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "accessmanagerreply_p.h"
 #include "accessmanager.h"
@@ -30,7 +15,7 @@
 
 #include <kurlauthorized.h>
 #include <kprotocolinfo.h>
-#include <qmimedatabase.h>
+#include <QMimeDatabase>
 
 #include <QtMath>
 #include <QSslConfiguration>
@@ -65,12 +50,12 @@ AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op
     }
 
     connect(kioJob, SIGNAL(redirection(KIO::Job*,QUrl)), SLOT(slotRedirection(KIO::Job*,QUrl)));
-    connect(kioJob, SIGNAL(percent(KJob*,ulong)), SLOT(slotPercent(KJob*,ulong)));
+    connect(kioJob, QOverload<KJob*,ulong>::of(&KJob::percent), this, &AccessManagerReply::slotPercent);
 
     if (qobject_cast<KIO::StatJob *>(kioJob)) {
-        connect(kioJob, SIGNAL(result(KJob*)), SLOT(slotStatResult(KJob*)));
+        connect(kioJob, &KJob::result, this, &AccessManagerReply::slotStatResult);
     } else {
-        connect(kioJob, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)));
+        connect(kioJob, &KJob::result, this, &AccessManagerReply::slotResult);
         connect(kioJob, SIGNAL(data(KIO::Job*,QByteArray)),
                 SLOT(slotData(KIO::Job*,QByteArray)));
         connect(kioJob, SIGNAL(mimetype(KIO::Job*,QString)),
@@ -117,8 +102,9 @@ AccessManagerReply::AccessManagerReply(const QNetworkAccessManager::Operation op
     setUrl(request.url());
     setOperation(op);
     setError(static_cast<QNetworkReply::NetworkError>(errorCode), errorMessage);
-    if (error() != QNetworkReply::NoError) {
-        QMetaObject::invokeMethod(this, "error", Qt::QueuedConnection, Q_ARG(QNetworkReply::NetworkError, error()));
+    const auto networkError = error();
+    if (networkError != QNetworkReply::NoError) {
+        QMetaObject::invokeMethod(this, "error", Qt::QueuedConnection, Q_ARG(QNetworkReply::NetworkError, networkError));
     }
 
     emitFinished(true, Qt::QueuedConnection);
@@ -169,7 +155,7 @@ bool AccessManagerReply::ignoreContentDisposition(const KIO::MetaData &metaData)
         return true;
     }
 
-    if (!metaData.contains(QStringLiteral("content-disposition-type"))) {
+    if (!metaData.contains(QLatin1String("content-disposition-type"))) {
         return true;
     }
 
@@ -199,17 +185,21 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
     }
 
     // Set the raw header information...
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList httpHeaders(metaData.value(QStringLiteral("HTTP-Headers")).split(QL1C('\n'), QString::SkipEmptyParts));
+#else
+    const QStringList httpHeaders(metaData.value(QStringLiteral("HTTP-Headers")).split(QL1C('\n'), Qt::SkipEmptyParts));
+#endif
     if (httpHeaders.isEmpty()) {
-        if (metaData.contains(QStringLiteral("charset"))) {
+        const auto charSetIt = metaData.constFind(QStringLiteral("charset"));
+        if (charSetIt != metaData.constEnd()) {
             QString mimeType = header(QNetworkRequest::ContentTypeHeader).toString();
-            mimeType += QStringLiteral(" ; charset=");
-            mimeType += metaData.value(QStringLiteral("charset"));
+            mimeType += QLatin1String(" ; charset=") + *charSetIt;
             //qDebug() << "changed content-type to" << mimeType;
             setHeader(QNetworkRequest::ContentTypeHeader, mimeType.toUtf8());
         }
     } else {
-        Q_FOREACH (const QString &httpHeader, httpHeaders) {
+        for (const QString &httpHeader : httpHeaders) {
             int index = httpHeader.indexOf(QL1C(':'));
             // Handle HTTP status line...
             if (index == -1) {
@@ -219,7 +209,11 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                     continue;
                 }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 QStringList statusLineAttrs(httpHeader.split(QL1C(' '), QString::SkipEmptyParts));
+#else
+                QStringList statusLineAttrs(httpHeader.split(QL1C(' '), Qt::SkipEmptyParts));
+#endif
                 if (statusLineAttrs.count() > 1) {
                     setAttribute(QNetworkRequest::HttpStatusCodeAttribute, statusLineAttrs.at(1));
                 }
@@ -231,7 +225,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 continue;
             }
 
-            const QString headerName = httpHeader.left(index);
+            const QStringRef headerName = httpHeader.leftRef(index);
             QString headerValue = httpHeader.mid(index + 1);
 
             // Ignore cookie header since it is handled by the http ioslave.
@@ -244,7 +238,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 continue;
             }
 
-            // Without overridding the corrected mime-type sent by kio_http, add
+            // Without overriding the corrected mime-type sent by kio_http, add
             // back the "charset=" portion of the content-type header if present.
             if (headerName.startsWith(QLatin1String("content-type"), Qt::CaseInsensitive)) {
 
@@ -253,7 +247,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 if (m_ignoreContentDisposition) {
                     // If the server returned application/octet-stream, try to determine the
                     // real content type from the disposition filename.
-                    if (mimeType == QStringLiteral("application/octet-stream")) {
+                    if (mimeType == QLatin1String("application/octet-stream")) {
                         const QString fileName(metaData.value(QStringLiteral("content-disposition-filename")));
                         QMimeDatabase db;
                         QMimeType mime = db.mimeTypeForFile((fileName.isEmpty() ? url().path() : fileName), QMimeDatabase::MatchExtension);
@@ -318,7 +312,7 @@ void AccessManagerReply::readHttpResponseHeaders(KIO::Job *job)
         // Allow handling of local resources such as man pages and file url...
         if (isLocalRequest(url())) {
             setHeader(QNetworkRequest::ContentLengthHeader, job->totalAmount(KJob::Bytes));
-            setAttribute(QNetworkRequest::HttpStatusCodeAttribute, "200");
+            setAttribute(QNetworkRequest::HttpStatusCodeAttribute, QStringLiteral("200"));
             emit metaDataChanged();
         }
         return;
@@ -343,7 +337,7 @@ int AccessManagerReply::jobError(KJob *kJob)
     case KIO::ERR_IS_DIRECTORY:
         // This error condition can happen if you click on an ftp link that points
         // to a directory instead of a file, e.g. ftp://ftp.kde.org/pub
-        setHeader(QNetworkRequest::ContentTypeHeader, "inode/directory");
+        setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("inode/directory"));
         setError(QNetworkReply::NoError, kJob->errorText());
         break;
     case KIO::ERR_CANNOT_CONNECT:
@@ -453,7 +447,12 @@ void AccessManagerReply::slotResult(KJob *kJob)
     if (!redirectUrl.isValid()) {
         setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::KioError), errcode);
         if (errcode && errcode != KIO::ERR_NO_CONTENT) {
-            emit error(error());
+            const auto networkError = error();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            emit error(networkError);
+#else
+            emit errorOccurred(networkError);
+#endif
         }
     }
 
@@ -468,7 +467,12 @@ void AccessManagerReply::slotResult(KJob *kJob)
 void AccessManagerReply::slotStatResult(KJob *kJob)
 {
     if (jobError(kJob)) {
-        emit error(error());
+        const auto networkError = error();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        emit error(networkError);
+#else
+        emit errorOccurred(networkError);
+#endif
         emitFinished(true);
         return;
     }
@@ -494,7 +498,12 @@ void AccessManagerReply::slotRedirection(KIO::Job *job, const QUrl &u)
     if (!KUrlAuthorized::authorizeUrlAction(QStringLiteral("redirect"), url(), u)) {
         qCWarning(KIO_WIDGETS) << "Redirection from" << url() << "to" << u << "REJECTED by policy!";
         setError(QNetworkReply::ContentAccessDenied, u.toString());
-        emit error(error());
+        const auto networkError = error();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        emit error(networkError);
+#else
+        emit errorOccurred(networkError);
+#endif
         return;
     }
     setAttribute(QNetworkRequest::RedirectionTargetAttribute, QUrl(u));
