@@ -1,29 +1,18 @@
-/* This file is part of the KDE project
-   Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
-   Based on konq_popupmenuplugin.h Copyright 2008 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2010 Sebastian Trueg <trueg@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
+    Based on konq_popupmenuplugin.h
+    SPDX-FileCopyrightText: 2008 David Faure <faure@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef KABSTRACTFILEITEMACTION_PLUGIN_H
 #define KABSTRACTFILEITEMACTION_PLUGIN_H
 
 #include "kiowidgets_export.h"
-#include <QtCore/QObject>
+#include <QObject>
 
 class QAction;
 class QMenu;
@@ -48,7 +37,7 @@ class KFileItemListProperties;
  * actions() to return the actions to want to add to the context menu.  Then
  * create a plugin in the usual KPluginFactory based way:
  * \code
- * K_PLUGIN_FACTORY_WITH_JSON(MyActionPluginFactory, myactionplugin.json, registerPlugin<MyActionPlugin>();)
+ * K_PLUGIN_CLASS_WITH_JSON(MyActionPlugin, "myactionplugin.json")
  * #include <thisfile.moc>
  * \endcode
  *
@@ -56,11 +45,10 @@ class KFileItemListProperties;
  *
  * \code
  * [Desktop Entry]
- * Encoding=UTF-8
  * Type=Service
  * Name=My fancy action plugin
  * X-KDE-Library=myactionplugin
- * ServiceTypes=KFileItemAction/Plugin
+ * X-KDE-ServiceTypes=KFileItemAction/Plugin
  * MimeType=some/mimetype;
  * \endcode
  *
